==> duiba-live-center-outapi-0.1.91-20211117.061759-2-sources.jar: cn/com/duiba/kjy/livecenter/api/enums/LIveCenterErrorCode.java <==
package cn.com.duiba.kjy.livecenter.api.enums;

import cn.com.duiba.live.tool.exception.ErrorCode;

/**
 * Created by dugq on 2020-03-25.
 */
public enum LIveCenterErrorCode implements ErrorCode {

    // 99 系统级别
    SYSTEM_ERROR("999999","系统错误"),
    PARAM_ERROR("999998","参数错误"),
    DO_NOT_CARE("990000","不关心错误码的异常，自我消化的异常。特殊标记"),


    // 直播公司
    SAVE_LIVE_USER("100001","保存直播用户失败"),
    SAVE_LIVE_AGENT("100002","保存直播代理人失败"),
    LIVE_NOT_EXIST("100003","直播间不存在"),

    //公司管理
    NOT_IN_SAME_TEAM("200001","非团队队员"),
    JOIN_TEAM_ERROR("200002","代理人加入团队失败"),

    //红包
    RED_PACKET_START_LIVE_EXIST("300001", "开播红包已经存在"),
    RED_PACKET_REAL_TIME_EXIST("300002", "尚有未领取完的实时红包"),
    RED_PACKET_START_LIVE_CAN_NO_UPDATE("300003", "开播红包直播开始后不能更改"),
    RED_PACKET_REAL_TIME_CAN_NO_UPDATE("300004", "实时红包不能更新"),
    RED_PACKET_RANDOM_ALGORITHM("300005", "红包拆分出错"),
    RED_PACKET_REAL_TIME_LIMIT("300006", "实时红包扣除限额失败"),
    RED_PACKET_AMOUNT_ERROR("300007", "红包金额错误"),

    //推广链接
    SPREAD_LINK_SAVE_ERROR("400001", "推广链接保存失败"),

    //指定中奖
    SPECIFY_STOCK_NOT_ENOUGH("500001","指定中奖库存不足"),
    SPECIFY_STOCK_INSERT_ERROR("500002","指定中奖记录插入异常"),
    SPECIFY_AWARD_CONF_INSERT_ERROR("500003","指定中奖配置插入异常"),

    // 小程序码
    BIND_MP_QRCODE_ERROR("600001", "绑定小程序码失败"),

    // 爆款商品
    BOOM_GOODS_APPOINTMENT("700001", "已预约商品"),
    ;

    private String code;
    private String desc;

    LIveCenterErrorCode(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    public String getHost() {
        return "06";
    }

    @Override
    public String getCode() {
        return this.code;
    }

    @Override
    public String getDesc() {
        return this.desc;
    }
}

==> duiba-live-center-outapi-0.2.19-20220627.021744-2-sources.jar: cn/com/duiba/kjy/livecenter/api/enums/LIveCenterErrorCode.java <==
package cn.com.duiba.kjy.livecenter.api.enums;

import cn.com.duiba.live.tool.exception.ErrorCode;

/**
 * Created by dugq on 2020-03-25.
 */
public enum LIveCenterErrorCode implements ErrorCode {

    // 99 系统级别
    SYSTEM_ERROR("999999","系统错误"),
    PARAM_ERROR("999998","参数错误"),
    DO_NOT_CARE("990000","不关心错误码的异常，自我消化的异常。特殊标记"),


    // 直播公司
    SAVE_LIVE_USER("100001","保存直播用户失败"),
    SAVE_LIVE_AGENT("100002","保存直播代理人失败"),
    LIVE_NOT_EXIST("100003","直播间不存在"),

    //公司管理
    NOT_IN_SAME_TEAM("200001","非团队队员"),
    JOIN_TEAM_ERROR("200002","代理人加入团队失败"),

    //红包
    RED_PACKET_START_LIVE_EXIST("300001", "开播红包已经存在"),
    RED_PACKET_REAL_TIME_EXIST("300002", "尚有未领取完的实时红包"),
    RED_PACKET_START_LIVE_CAN_NO_UPDATE("300003", "开播红包直播开始后不能更改"),
    RED_PACKET_REAL_TIME_CAN_NO_UPDATE("300004", "实时红包不能更新"),
    RED_PACKET_RANDOM_ALGORITHM("300005", "红包拆分出错"),
    RED_PACKET_REAL_TIME_LIMIT("300006", "实时红包扣除限额失败"),
    RED_PACKET_AMOUNT_ERROR("300007", "红包金额错误"),

    //推广链接
    SPREAD_LINK_SAVE_ERROR("400001", "推广链接保存失败"),

    //指定中奖
    SPECIFY_STOCK_NOT_ENOUGH("500001","指定中奖库存不足"),
    SPECIFY_STOCK_INSERT_ERROR("500002","指定中奖记录插入异常"),
    SPECIFY_AWARD_CONF_INSERT_ERROR("500003","指定中奖配置插入异常"),

    // 小程序码
    BIND_MP_QRCODE_ERROR("600001", "绑定小程序码失败"),

    // 爆款商品
    BOOM_GOODS_APPOINTMENT("700001", "已预约商品"),

    // 优惠券
    NO_COUPONS_RECEIVED("800001", "没有已领取的优惠券"),

    //直播公司
    COMPANY_NOT_EXIST("900001", "直播公司不存在"),

    //社群
    LAUNCH_NOT_EXIST("900002", "聚合链路不存在"),
    DRAINAGE_NOT_EXIST("900003", "不可重复选择引流链路"),
    DRAINAGE_ORIGIN_REPEAT("900004", "多个引流链路包含了同一用户人群"),
    ;

    private String code;
    private String desc;

    LIveCenterErrorCode(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    public String getHost() {
        return "06";
    }

    @Override
    public String getCode() {
        return this.code;
    }

    @Override
    public String getDesc() {
        return this.desc;
    }
}
